@@ -76,7 +76,7 @@ testWaylandBackend::testWaylandBackend(QObject *parent)
 {
     qputenv("KSCREEN_LOGGING", "false");
     m_server = new WaylandTestServer(this);
-    m_server->setConfig(TEST_DATA + QStringLiteral("multipleoutput.json"));
+    m_server->setConfig(QLatin1String(TEST_DATA) + QLatin1String("multipleoutput.json"));
 }
 
 void testWaylandBackend::initTestCase()
@@ -85,7 +85,7 @@ void testWaylandBackend::initTestCase()
     KScreen::BackendManager::instance()->shutdownBackend();
     // This is how KWayland will pick up the right socket,
     // and thus connect to our internal test server.
-    setenv("WAYLAND_DISPLAY", s_socketName.toLocal8Bit(), 1);
+    setenv("WAYLAND_DISPLAY", s_socketName.toLocal8Bit().constData(), 1);
     m_server->start();
 
     GetConfigOperation *op = new GetConfigOperation();
@@ -150,7 +150,7 @@ void testWaylandBackend::verifyOutputs()
         QVERIFY(output->geometry() != QRectF(1,1,1,1));
         QVERIFY(output->geometry() != QRectF());
         QVERIFY(output->sizeMm() != QSize());
-        QVERIFY(output->edid() != 0);
+        QVERIFY(output->edid() != nullptr);
         QVERIFY(output->preferredModes().size() == 1);
         QCOMPARE(output->rotation(), Output::None);
         QVERIFY(!ids.contains(output->id()));
@@ -274,7 +274,7 @@ void testWaylandBackend::testEdid()
 
     QByteArray data = QByteArray::fromBase64("AP///////wAQrBbwTExLQQ4WAQOANCB46h7Frk80sSYOUFSlSwCBgKlA0QBxTwEBAQEBAQEBKDyAoHCwI0AwIDYABkQhAAAaAAAA/wBGNTI1TTI0NUFLTEwKAAAA/ABERUxMIFUyNDEwCiAgAAAA/QA4TB5REQAKICAgICAgAToCAynxUJAFBAMCBxYBHxITFCAVEQYjCQcHZwMMABAAOC2DAQAA4wUDAQI6gBhxOC1AWCxFAAZEIQAAHgEdgBhxHBYgWCwlAAZEIQAAngEdAHJR0B4gbihVAAZEIQAAHowK0Iog4C0QED6WAAZEIQAAGAAAAAAAAAAAAAAAAAAAPg==");
 
-    auto edid = new Edid(data);
+    QScopedPointer<Edid> edid(new Edid(data));
     QVERIFY(edid->isValid());
 
     GetConfigOperation *op = new GetConfigOperation();
