@@ -43,16 +43,16 @@ class XRandR : public KScreen::AbstractBackend
 
     public:
         explicit XRandR();
-        virtual ~XRandR();
+        ~XRandR() override;
 
-        QString name() const Q_DECL_OVERRIDE;
-        QString serviceName() const Q_DECL_OVERRIDE;
-        KScreen::ConfigPtr config() const Q_DECL_OVERRIDE;
-        void setConfig(const KScreen::ConfigPtr &config) Q_DECL_OVERRIDE;
-        bool isValid() const Q_DECL_OVERRIDE;
-        QByteArray edid(int outputId) const Q_DECL_OVERRIDE;
+        QString name() const override;
+        QString serviceName() const override;
+        KScreen::ConfigPtr config() const override;
+        void setConfig(const KScreen::ConfigPtr &config) override;
+        bool isValid() const override;
+        QByteArray edid(int outputId) const override;
 
-        static quint8 *outputEdid(xcb_randr_output_t outputId, size_t &len);
+        static QByteArray outputEdid(xcb_randr_output_t outputId);
         static xcb_randr_get_screen_resources_reply_t* screenResources();
         static xcb_screen_t* screen();
         static xcb_window_t rootWindow();
