@@ -34,8 +34,8 @@ XRandROutput::XRandROutput(xcb_randr_output_t id, XRandRConfig *config)
     , m_config(config)
     , m_id(id)
     , m_type(KScreen::Output::Unknown)
-    , m_primary(0)
-    , m_crtc(0)
+    , m_primary(false)
+    , m_crtc(nullptr)
 {
     init();
 }
@@ -89,9 +89,9 @@ XRandRMode* XRandROutput::currentMode() const
     if (!m_crtc) {
         return nullptr;
     }
-    int modeId = m_crtc->mode();
+    unsigned int modeId = m_crtc->mode();
     if (!m_modes.contains(modeId)) {
-        return 0;
+        return nullptr;
     }
 
     return m_modes[modeId];
@@ -105,16 +105,8 @@ KScreen::Output::Rotation XRandROutput::rotation() const
 QByteArray XRandROutput::edid() const
 {
     if (m_edid.isNull()) {
-        size_t len;
-        quint8 *data = XRandR::outputEdid(m_id, len);
-        if (data) {
-            m_edid = QByteArray((char *) data, len);
-            delete[] data;
-        } else {
-            m_edid = QByteArray();
-        }
+        m_edid = XRandR::outputEdid(m_id);
     }
-
     return m_edid;
 }
 
@@ -174,7 +166,7 @@ void XRandROutput::update(xcb_randr_crtc_t crtc, xcb_randr_mode_t mode, xcb_rand
         if (crtc == XCB_NONE && mode == XCB_NONE) {
             // Monitor has been disabled
             m_crtc->disconectOutput(m_id);
-            m_crtc = 0;
+            m_crtc = nullptr;
         } else {
             m_crtc = m_config->crtc(crtc);
             m_crtc->connectOutput(m_id);
@@ -255,9 +247,9 @@ void XRandROutput::updateModes(const XCB::OutputInfo &outputInfo)
 
 KScreen::Output::Type XRandROutput::fetchOutputType(xcb_randr_output_t outputId, const QString &name)
 {
-    QByteArray type = typeFromProperty(outputId);
+    QString type = QString::fromUtf8(typeFromProperty(outputId));
     if (type.isEmpty()) {
-        type = name.toLocal8Bit();
+        type = name;
     }
 
     return Utils::guessOutputType(type, name);
@@ -276,7 +268,7 @@ QByteArray XRandROutput::typeFromProperty(xcb_randr_output_t outputId)
 
     auto cookie = xcb_randr_get_output_property(XCB::connection(), outputId, atomType->atom,
                                                 XCB_ATOM_ANY, 0, 100, false, false);
-    XCB::ScopedPointer<xcb_randr_get_output_property_reply_t> reply(xcb_randr_get_output_property_reply(XCB::connection(), cookie, NULL));
+    XCB::ScopedPointer<xcb_randr_get_output_property_reply_t> reply(xcb_randr_get_output_property_reply(XCB::connection(), cookie, nullptr));
     if (!reply) {
         return type;
     }
