@@ -61,18 +61,17 @@ BackendManager *BackendManager::instance()
 }
 
 BackendManager::BackendManager()
-    : QObject()
-    , mInterface(0)
+    : mInterface(nullptr)
     , mCrashCount(0)
     , mShuttingDown(false)
     , mRequestsCounter(0)
-    , mLoader(0)
+    , mLoader(nullptr)
     , mMethod(OutOfProcess)
 {
     Log::instance();
-    // Decide wether to run in, or out-of-process
+    // Decide whether to run in, or out-of-process
 
-    // if KSCREEN_BACKEND_INPROCESS is set explicitely, we respect that
+    // if KSCREEN_BACKEND_INPROCESS is set explicitly, we respect that
     const auto _inprocess = qgetenv("KSCREEN_BACKEND_INPROCESS");
     if (!_inprocess.isEmpty()) {
 
@@ -146,7 +145,7 @@ QFileInfo BackendManager::preferredBackend(const QString &backend)
      *
      */
     QString backendFilter;
-    const auto env_kscreen_backend = qgetenv("KSCREEN_BACKEND");
+    const auto env_kscreen_backend = QString::fromUtf8(qgetenv("KSCREEN_BACKEND"));
     if (!backend.isEmpty()) {
         backendFilter = backend;
     } else if (!env_kscreen_backend.isEmpty()) {
@@ -235,10 +234,11 @@ KScreen::AbstractBackend *BackendManager::loadBackendInProcess(const QString &na
     if (mLoader == nullptr) {
         mLoader = new QPluginLoader(this);
     }
+    auto test_data_equals = QStringLiteral("TEST_DATA=");
     QVariantMap arguments;
     auto beargs = QString::fromLocal8Bit(qgetenv("KSCREEN_BACKEND_ARGS"));
-    if (beargs.startsWith("TEST_DATA=")) {
-        arguments["TEST_DATA"] = beargs.remove("TEST_DATA=");
+    if (beargs.startsWith(test_data_equals)) {
+        arguments[QStringLiteral("TEST_DATA")] = beargs.remove(test_data_equals);
     }
     auto backend = BackendManager::loadBackendPlugin(mLoader, name, arguments);
     //qCDebug(KSCREEN) << "Connecting ConfigMonitor to backend.";
@@ -272,7 +272,7 @@ void BackendManager::requestBackend()
             if (pos == -1) {
                 continue;
             }
-            arguments.insert(arg.left(pos), arg.mid(pos + 1));
+            arguments.insert(QString::fromUtf8(arg.left(pos)), arg.mid(pos + 1));
         }
     }
 
@@ -377,7 +377,7 @@ void BackendManager::invalidateInterface()
 {
     Q_ASSERT(mMethod == OutOfProcess);
     delete mInterface;
-    mInterface = 0;
+    mInterface = nullptr;
     mBackendService.clear();
 }
 
