@@ -111,7 +111,6 @@ bool Config::canBeApplied(const ConfigPtr &config, ValidityFlags flags)
     }
 
     QRect rect;
-    QSize outputSize;
     OutputPtr currentOutput;
     const OutputList outputs = config->outputs();
     int enabledOutputsCount = 0;
@@ -368,7 +367,8 @@ QDebug operator<<(QDebug dbg, const KScreen::ConfigPtr &config)
 {
     if (config) {
         dbg << "KScreen::Config(";
-        for (const auto output : config->outputs()) {
+        const auto outputs = config->outputs();
+        for (const auto &output : outputs) {
             if (output->isConnected()) {
                 dbg << endl << output;
             }
