@@ -76,7 +76,7 @@ class Q_DECL_HIDDEN Edid::Private
     bool parse(const QByteArray &data);
     int edidGetBit(int in, int bit) const;
     int edidGetBits(int in, int begin, int end) const;
-    double edidDecodeFraction(int high, int low) const;
+    float edidDecodeFraction(int high, int low) const;
     QString edidParseString(const quint8 *data) const;
 
     bool valid;
@@ -242,8 +242,8 @@ QQuaternion Edid::white() const
 bool Edid::Private::parse(const QByteArray &rawData)
 {
     quint32 serial;
-    const quint8 *data = (quint8*) rawData.constData();
-    size_t length = rawData.length();
+    const quint8 *data = reinterpret_cast<const quint8*>(rawData.constData());
+    int length = rawData.length();
 
     /* check header */
     if (length < 128) {
@@ -270,10 +270,10 @@ bool Edid::Private::parse(const QByteArray &rawData)
 
     // load the PNP_IDS file and load the vendor name
     if (!pnpId.isEmpty()) {
-        QFile pnpIds(PNP_IDS);
+        QFile pnpIds(QStringLiteral(PNP_IDS));
         if (pnpIds.open(QIODevice::ReadOnly)) {
             while (!pnpIds.atEnd()) {
-                QString line = pnpIds.readLine();
+                QString line = QString::fromUtf8(pnpIds.readLine());
                 if (line.startsWith(pnpId)) {
                     QStringList parts = line.split(QLatin1Char('\t'));
                     if (parts.size() == 2) {
@@ -306,9 +306,9 @@ bool Edid::Private::parse(const QByteArray &rawData)
 
     /* get gamma */
     if (data[GCM_EDID_OFFSET_GAMMA] == 0xff) {
-        gamma = 1.0f;
+        gamma = 1.0;
     } else {
-        gamma = (static_cast<float>(data[GCM_EDID_OFFSET_GAMMA] / 100) + 1);
+        gamma = data[GCM_EDID_OFFSET_GAMMA] / 100.0 + 1.0;
     }
 
     /* get color red */
@@ -361,12 +361,12 @@ bool Edid::Private::parse(const QByteArray &rawData)
             if (data[i+3+9] != 0xff) {
                 /* extended EDID block(1) which contains
                                      * a better gamma value */
-                gamma = ((float) data[i+3+9] / 100) + 1;
+                gamma = (data[i+3+9] / 100.0) + 1;
             }
             if (data[i+3+14] != 0xff) {
                 /* extended EDID block(2) which contains
                                      * a better gamma value */
-                gamma = ((float) data[i+3+9] / 100) + 1;
+                gamma = (data[i+3+9] / 100.0) + 1;
             }
         }
     }
@@ -374,7 +374,7 @@ bool Edid::Private::parse(const QByteArray &rawData)
     // calculate checksum
     QCryptographicHash hash(QCryptographicHash::Md5);
     hash.addData(reinterpret_cast<const char *>(data), length);
-    checksum = hash.result().toHex();
+    checksum = QString::fromLatin1(hash.result().toHex());
 
     valid = true;
     return valid;
@@ -392,13 +392,12 @@ int Edid::Private::edidGetBits(int in, int begin, int end) const
         return (in >> begin) & mask;
 }
 
-double Edid::Private::edidDecodeFraction(int high, int low) const
+float Edid::Private::edidDecodeFraction(int high, int low) const
 {
-        double result = 0.0;
-        int i;
+        float result = 0.0;
 
         high = (high << 2) | low;
-        for (i = 0; i < 10; ++i) {
+        for (int i = 0; i < 10; ++i) {
             result += edidGetBit(high, i) * pow(2, i - 10);
         }
         return result;
@@ -406,14 +405,14 @@ double Edid::Private::edidDecodeFraction(int high, int low) const
 
 QString Edid::Private::edidParseString(const quint8 *data) const
 {
-        QString text;
-
-        /* this is always 12 bytes, but we can't guarantee it's null
+        /* this is always 13 bytes, but we can't guarantee it's null
          * terminated or not junk. */
-        text = QString::fromLocal8Bit((const char*) data, 12);
-
-        // Remove newlines, extra spaces and stuff
-        text = text.simplified();
+        auto text = QString::fromLatin1(reinterpret_cast<const char*>(data), 13).simplified();
 
+        for (int i = 0; i < text.length(); ++i) {
+            if (!text.at(i).isPrint()) {
+                text[i] = '-';
+            }
+        }
         return text;
 }
