@@ -46,8 +46,9 @@ class KSCREEN_EXPORT Output : public QObject
         Q_PROPERTY(QString name READ name WRITE setName NOTIFY outputChanged)
         Q_PROPERTY(Type type READ type WRITE setType NOTIFY outputChanged)
         Q_PROPERTY(QString icon READ icon WRITE setIcon NOTIFY outputChanged)
-        Q_PROPERTY(ModeList modes READ modes CONSTANT)
+        Q_PROPERTY(ModeList modes READ modes NOTIFY modesChanged)
         Q_PROPERTY(QPoint pos READ pos WRITE setPos NOTIFY posChanged)
+        Q_PROPERTY(QSize size READ size WRITE setSize NOTIFY sizeChanged)
         Q_PROPERTY(Rotation rotation READ rotation WRITE setRotation NOTIFY rotationChanged)
         Q_PROPERTY(QString currentModeId READ currentModeId WRITE setCurrentModeId NOTIFY currentModeIdChanged)
         Q_PROPERTY(QString preferredModeId READ preferredModeId CONSTANT)
@@ -57,6 +58,8 @@ class KSCREEN_EXPORT Output : public QObject
         Q_PROPERTY(QList<int> clones READ clones WRITE setClones NOTIFY clonesChanged)
         Q_PROPERTY(KScreen::Edid* edid READ edid CONSTANT)
         Q_PROPERTY(QSize sizeMm READ sizeMm CONSTANT)
+        Q_PROPERTY(qreal scale READ scale WRITE setScale NOTIFY scaleChanged)
+
 
         enum Type {
             Unknown,
@@ -84,7 +87,7 @@ class KSCREEN_EXPORT Output : public QObject
         };
 
         explicit Output();
-        virtual ~Output();
+        ~Output() override;
 
         OutputPtr clone() const;
 
@@ -111,7 +114,7 @@ class KSCREEN_EXPORT Output : public QObject
         void setPreferredModes(const QStringList &modes);
         QStringList preferredModes() const;
         /**
-         * Returns the preferred mode with higer resolution and refresh
+         * Returns the preferred mode with higher resolution and refresh
          */
         Q_INVOKABLE QString preferredModeId() const;
         /**
@@ -122,6 +125,27 @@ class KSCREEN_EXPORT Output : public QObject
         QPoint pos() const;
         void setPos(const QPoint& pos);
 
+        /***
+         * Returns actual size being rendered in the output
+         *
+         * The returned valued is after transformations have been applied to
+         * the resolution of the current mode.
+         *
+         * For example if currentMode is 1280x800 but it is a vertical screen
+         * the returned size will be 800x1280.
+         *
+         * If that same resolution (1280x800) is transformed and scale x2, the
+         * value returned will be 2560x1600.
+         *
+         * This property reflects the currently active output configuration and
+         * is not affected by current mode or orientation change made by user
+         * until the config is applied.
+         *
+         * @since 5.4
+         */
+        QSize size() const;
+        void setSize(const QSize& size);
+
         Rotation rotation() const;
         void setRotation(Rotation rotation);
         /**
@@ -147,27 +171,66 @@ class KSCREEN_EXPORT Output : public QObject
         void setEdid(const QByteArray &rawData);
         Edid* edid() const;
 
+        /**
+         * Returns the physical size of the screen in milimeters.
+         *
+         * @note Some broken GPUs or monitors return the size in centimeters instead
+         * of millimeters. KScreen at the moment is not sanitizing the values.
+         */
         QSize sizeMm() const;
         void setSizeMm(const QSize &size);
 
         /**
-         * Returns a rectangle containing the current output position and size.
+         * Returns a rectangle containing the currently set output position and
+         * size.
          *
-         * The geometry takes rotation into account, so if an 1920x1200 output
-         * is rotated by 90 deg, the geometry will be (0, 0, 1200, 1920)!
+         * The geometry also reflects current orientation (i.e. if current mode
+         * is 1920x1080 and orientation is @p KScreen::Output::Left, then the
+         * size of the returned rectangle will be 1080x1920.
+         *
+         * This property contains the current settings stored in the particular
+         * Output object, so it is updated even when user changes current mode
+         * or orientation without applying the whole config/
          */
         QRect geometry() const;
 
+        /**
+         * returns the scaling factor to use for this output
+         *
+         * @since 5.9
+         */
+        qreal scale() const;
+
+        /**
+         * Set the scaling factor for this output.
+         *
+         * @arg factor Scale factor to use for this output, the backend may or may not
+         * be able to deal with non-integer values, in that case, the factor gets rounded.
+         *
+         * @since 5.9
+         */
+        void setScale(qreal factor);
+
         void apply(const OutputPtr &other);
     Q_SIGNALS:
         void outputChanged();
         void posChanged();
+        void sizeChanged();
         void currentModeIdChanged();
         void rotationChanged();
         void isConnectedChanged();
         void isEnabledChanged();
         void isPrimaryChanged();
         void clonesChanged();
+        void scaleChanged();
+
+        /** The mode list changed.
+         *
+         * This may happen when a mode is added or changed.
+         *
+         * @since 5.8.3
+         */
+        void modesChanged();
 
     private:
         Q_DISABLE_COPY(Output)
